require "spec_helper"

shared_examples "'A Marmita' client" do
  
  describe "#login" do
    let(:login_url) { "http://www.amarmita.com/login.php?user=#{env.email}&psw=#{env.pass}" }

    context 'when using valid credentials' do
      before { stub_request(:get, login_url).to_return(status: 200, body: '1') }

      it { expect(a_marmita.login(env.email, env.pass)).to be(true) }
    end

    context 'when using invalid credentials' do
      before do
        env.pass = 'fake'
        stub_request(:get, "http://www.amarmita.com/login.php?user=#{env.email}&psw=#{env.pass}").to_return(status: 200, body: '-1')
      end

      it do
        expect(a_marmita.login(env.email, env.pass)).to be(false)
        env.pass = ENV['PASS']
      end
    end
  end


  describe "#add_to_cart" do
    before { a_marmita.set_credentials(env.email, env.pass) }

    context 'when adding a valid id, quantity and date' do
      it { expect(a_marmita.add_to_cart(2846, '2014-4-11', 1)).to be(:ok) }
    end

    context 'when adding a invalid id and a valid quantity and date' do
      it { expect(a_marmita.add_to_cart(-1, '2014-4-11', 1)).to be(:ok) }
    end

    context 'when adding a valid id and date and a invalid quantity' do
      it { expect(a_marmita.add_to_cart(2846, '2014-4-11', -1)).to be(:ok) }
    end

    context 'when adding a valid id and quantity and a invalid date' do
      it { expect(a_marmita.add_to_cart(2846, '2014-4-1', 1)).to be(:bad_date) }
    end
  end

  describe "#cart" do
    before { a_marmita.set_credentials(env.email, env.pass) }

    context 'when adding to the cart, the cart list' do
      it { expect(a_marmita.cart.length).to be > 1 }
    end
  end

end

describe 'AMarmita module' do
  it_behaves_like "'A Marmita' client" do
    let(:a_marmita) { AMarmita }
  end
end

describe 'AMarmita::Client class' do
  it_behaves_like "'A Marmita' client" do
    let(:a_marmita) { AMarmita.new_client }
  end
end
